==> maxim_py-3.7.2.tar.gz: maxim_py-3.7.2/maxim/logger/livekit/job_context.py <==
import functools
import inspect
import traceback
from uuid import uuid4

from livekit.agents import JobContext

from ...scribe import scribe
from .store import get_session_store


def intercept_participant_available(self: JobContext, *args, **kwargs):
    if not args or len(args) == 0:
        return
    participant = args[0]
    if not participant:
        return
    trace = get_session_store().get_current_trace_for_room_id(id(self.room))
    if trace is None:
        return
    trace.event(
        str(uuid4()),
        "Participant available",
        {"type": "participant_available"},
        {"participant": participant},
    )


def pre_hook(self, hook_name, args, kwargs):
    try:
        scribe().debug(
            f"[{self.__class__.__name__}] {hook_name} called; args={args}, kwargs={kwargs}"
        )
    except Exception as e:
        scribe().error(
            f"[{self.__class__.__name__}] {hook_name} failed; error={str(e)}\n{traceback.format_exc()}"
        )


def post_hook(self, result, hook_name, args, kwargs):
    try:
        scribe().debug(
            f"[{self.__class__.__name__}] {hook_name} completed; result={result}"
        )
        if hook_name == "_participant_available":
            intercept_participant_available(self, *args, **kwargs)
    except Exception as e:
        scribe().error(
            f"[{self.__class__.__name__}] {hook_name} failed; error={str(e)}\n{traceback.format_exc()}"
        )


def instrument_job_context(orig, name):
    if inspect.iscoroutinefunction(orig):

        async def async_wrapper(self, *args, **kwargs):
            pre_hook(self, name, args, kwargs)
            result = None
            try:
                result = await orig(self, *args, **kwargs)
                return result
            finally:
                post_hook(self, result, name, args, kwargs)            

        wrapper = async_wrapper
    else:

        def sync_wrapper(self, *args, **kwargs):
            pre_hook(self, name, args, kwargs)
            result = None
            try:
                result = orig(self, *args, **kwargs)
                return result
            finally:
                post_hook(self, result, name, args, kwargs)

        wrapper = sync_wrapper
    return functools.wraps(orig)(wrapper)

==> maxim_py-3.8.5.tar.gz: maxim_py-3.8.5/maxim/logger/livekit/job_context.py <==
import functools
import inspect
import traceback
from uuid import uuid4

from livekit.agents import JobContext

from ...scribe import scribe
from .store import get_session_store


def intercept_participant_available(self: JobContext, *args, **kwargs):
    if not args or len(args) == 0:
        return
    participant = args[0]
    if not participant:
        return
    trace = get_session_store().get_current_trace_for_room_id(id(self.room))
    if trace is None:
        return
    trace.event(
        str(uuid4()),
        "Participant available",
        {"type": "participant_available"},
        {"participant": participant},
    )


def pre_hook(self, hook_name, args, kwargs):
    try:
        scribe().debug(
            f"[Internal][{self.__class__.__name__}] {hook_name} called; args={args}, kwargs={kwargs}"
        )
    except Exception as e:
        scribe().error(
            f"[Internal][{self.__class__.__name__}] {hook_name} failed; error={str(e)}\n{traceback.format_exc()}"
        )


def post_hook(self, result, hook_name, args, kwargs):
    try:
        scribe().debug(
            f"[Internal][{self.__class__.__name__}] {hook_name} completed; result={result}"
        )
        if hook_name == "_participant_available":
            intercept_participant_available(self, *args, **kwargs)
    except Exception as e:
        scribe().error(
            f"[Internal][{self.__class__.__name__}] {hook_name} failed; error={str(e)}\n{traceback.format_exc()}"
        )


def instrument_job_context(orig, name):
    if inspect.iscoroutinefunction(orig):

        async def async_wrapper(self, *args, **kwargs):
            pre_hook(self, name, args, kwargs)
            result = None
            try:
                result = await orig(self, *args, **kwargs)
                return result
            finally:
                post_hook(self, result, name, args, kwargs)            

        wrapper = async_wrapper
    else:

        def sync_wrapper(self, *args, **kwargs):
            pre_hook(self, name, args, kwargs)
            result = None
            try:
                result = orig(self, *args, **kwargs)
                return result
            finally:
                post_hook(self, result, name, args, kwargs)

        wrapper = sync_wrapper
    return functools.wraps(orig)(wrapper)
